==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/sloupeczpracovanedochazky.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Editace;
use Ron\DateUtils;
use Ron\StringUtils;
use Ron\TextManager;

/**
 * Class SloupecZpracovaneDochazky
 * Nastaveni sloupce dennich vysledku
 */
class SloupecZpracovaneDochazky
{
    /** @var string */
    var $nadpis;

    /** @var string   Typ zobrazenych dat ve sloupci */
    var $typ;

    /** @var string */
    var $kodCasoveSlozky;
    /** @var string     Jednotka pro denni vysledek - H, D, K, P */
    var $jednotka;
    /** @var bool       priznak, jestli se ma v hintu zobrazit puvodni dochazka */
    var $zobrazitPuvodni;
    /** @var bool       priznak, jestli se maji v hintu zobrazit pruchody */
    var $zobrazitPruchody;
    /** @var bool       priznak, jestli se maji zobrazit nulove hodnoty */
    var $zobrazitNuloveHodnoty;

    /** @var bool       jestli se ma sloupec zobrazit (default true, lze skryt napr. pomoci rozdeleni) */
    var $lzeZobrazit;
    /** @var bool       jestli je povolena editace sloupce */
    var $lzeEditovat;
    /** @var bool       jestli se muze editovat v jeste nezpracovanych dnech */
    var $editovatNezpracovanou;

    /** @var string     pro ktere rozdeleni se ma zobrazit - format textu je "typ/seznam kodu oddelenych strednikem" */
    public $filtrRozdeleni;
    /** @var string     kod profilu - sloupec se zobrazi jen uzivatelum se zadanym profilem */
    public $profil;
    /** @var string     kod prava, kterym se ridi zobrazeni sloupce */
    public $pravo;
    /** @var string     kod prava, kterym se ridi editace sloupce */
    public $pravoEditace;

    /** @var string     nadpis ve filtru - uzivatel si muze tuto polozku vypnout */
    public $filtrCaption;
    /** @var string     jedinecny kod pro zapinani a zapamatovani filtru */
    public $filtrKey;
    /** @var string     prepinaci skupina filtru  */
    public $filtrGroup;

    /** @var string     Nazev editu v HTML - pouzije se jen v nekterych sloupcich (DOCH1, DOCH2) - slouzi pro rozliseni vice sloupcu stejneho typu s ruznym nastavenim */
    var $name;

    /** @var string     u typu DOCH1 a DOCH2 se nastavi kod operace, ktera se vklada pri editaci prichodu a/nebo odchodu */
    var $operace;
    /** @var string     u typu DOCH1 a DOCH2 urcuje seznam operaci, ktere se budou zobrazovat, ostatni se ignoruji  */
    var $zapocitatOperace;
    /** @var string     u typu DOCH1 a DOCH2 urcuje seznam operaci, ktere se pri editaci "promazou" - lze pouzit napr. pro promazani prestavek */
    var $prepsatOperace;
    /** @var bool       priznak, ze se ma pouzit zobrazeny cas (defaultne zapocteny)  */
    var $zobrazenyCas;

    /** @var int        DV_ROZDELENI, DENNIVYSLEDEK_R, DENNIVYSLEDEK_R_E */
    var $typRozdeleni;
    /** @var string     Absence, graficka, DOCH_Z, DV_ROZDELENI, DENNIVYSLEDEK_R, DENNIVYSLEDEK_R_E */
    var $format;

    /** @var bool       u DOCH_G urcuje, jestli se ma zobrazit informace o smene. Mozne hodnoty: KAL/KAP/1/0, defaultni je 1 (=AUTO) */
    var $zobrazitSmenu;

    /** @var float      hodnota, ktera se zobrazi v paticce (mesicni vysledek) */
    var $soucet;
    var $zobrazitGraf;

    /** @var string     zarovnani */
    var $align;
    var $style;
    var $class;
    var $headerClass;

    /** @var bool       priznak, ze se nema pri zobrazeni pouzivat htmlconvert */
    var $noHtmlConvert;

    function __construct()
    {
        $this ->lzeZobrazit = true;
    }


    /**
     * @param string $nastaveniSloupce
     */
    function nastavPodleRetezce($nastaveniSloupce)
    {
        $poma = explode(':', $nastaveniSloupce, 5);

        $this ->typ = $poma[0];
        $this ->align = 'left';
        $this ->lzeEditovat = false;

        switch ($this ->typ) {
            case 'DV' : // DV:<kod>:H/D/K:0/1:Nadpis sloupce  -> denni vysledek
                $this ->kodCasoveSlozky = $poma[1];
                $this ->jednotka = $poma[2]; // H/D/K
                $this ->lzeEditovat = $poma[3] == '1';
                $this ->nadpis = $poma[4];
                $this ->align = 'right';
                break;

            case 'SCHVAL1' :
            case 'SCHVAL2' :
            case 'SCHVAL3' :
            case 'SCHVAL' :
                $this ->headerClass = 'schvaleni';
                break;

            case 'DATUM' :
                $this ->align = 'center';
                $this ->nadpis = $poma[1];
                if (!$this ->nadpis) $this ->nadpis = TextManager::_('Date');
                break;

            case 'P' : // P:0/1:Nadpis sloupce -> poznamka ke dni
                $this ->lzeEditovat = $poma[1] == '1';
                $this ->nadpis = $poma[2];
                break;

            default :
                $this ->nadpis = $poma[1];
                break;
        }

    }


    /**
     * Nacte nastaveni z asociativniho pole (nactene z XML)
     * @param array $settings
     */
    function loadSettings($settings)
    {
        $this ->align = 'left';
        $this ->lzeEditovat = false;
        $this ->noHtmlConvert = false;

        $this ->typ = $settings['typ'];
        $this ->nadpis = TextManager::_($settings['nadpis']);

        $this ->jednotka = $settings['jednotka']; // H/D/K/P

        $this->name = $settings['name'];

        switch ($this ->typ) {
            case 'DV' :
                if ($this ->jednotka != 'P') $this ->align = 'right';
                break;

            case 'DV_CHECK' :
                $this ->align = 'center';
                break;

            case 'SCHVAL1' :
            case 'SCHVAL2' :
            case 'SCHVAL3' :
            case 'SCHVAL' :
                $this ->headerClass = 'schvaleni';
                break;

            case 'DATUM' :
                $this ->align = 'center';
                if (!$this ->nadpis) $this ->nadpis = TextManager::_('Date');
                break;

            case 'DV_ROZDELENI' :
            case 'DENNIVYSLEDEK_R' :
            case 'DENNIVYSLEDEK_R_E' :
                $this ->typRozdeleni = (int)$settings['typrozdeleni'];
                if (!$this ->nadpis) $this ->nadpis = TextManager::_('Rozdeleni_vysledku');
                $this ->noHtmlConvert = true;
                break;

            case 'ABSENCE' :
            case 'DOC' : // dokumenty
            case 'KONTROLY' :
                $this ->noHtmlConvert = true;
                break;


            case 'DOCH1' :
            case 'DOCH2' :
                $this ->align = 'center';
                $this ->operace = $settings['operace'];
                $this ->zapocitatOperace = strtolower($settings['zapocitatoperace']);
                $this ->prepsatOperace = strtolower($settings['prepsatoperace']);
                $this ->zobrazitPuvodni = $settings['hintpuvodni'] == '1';
                $this ->zobrazitPruchody = $settings['hintpruchody'] == '1';
                $this ->zobrazenyCas = $settings['zobrazenycas'] == '1';
                $this ->name = $this ->name ?: 'DOCH';
                break;

            case 'DOCH_G' :
                $this ->zobrazitSmenu = $settings['zobrazitsmenu'];
                if ($this ->zobrazitSmenu === '') $this ->zobrazitSmenu = '1'; // defaultne automaticky podle kalendare
                break;
        }

        $this ->kodCasoveSlozky = $settings['kod'];
        $this ->lzeEditovat = $settings['editace'] == '1';
        //$this ->f_HTMLName = $element ->getAttribute('htmlname');
        $this ->editovatNezpracovanou = $settings['editovatnezpracovanou'] == '1';

        $this ->filtrRozdeleni = $settings['rozdeleni'];
        $this ->profil = $settings['profil'];
        $this ->pravo = $settings['pravo'];
        $this ->pravoEditace = $settings['pravoEditace'];

        $this ->zobrazitNuloveHodnoty = $settings['zobrazitNuloveHodnoty'] == '1';

        $this ->filtrKey = isset($settings['kodFiltru']) ? $settings['kodFiltru'] : $settings['kodfiltru'];
        $this ->filtrCaption = TextManager::_($settings['filtr']);
        $this ->filtrGroup = isset($settings['filtrGroup']) ? $settings['filtrGroup'] : $settings['filtrgroup'];

        $this ->format = $settings['format'];
        $this ->zobrazitGraf = isset($settings['zobrazitGraf']) ? $settings['zobrazitGraf'] == '1' : $settings['zobrazitgraf'] == '1';

        if ($settings['headerclass']) $this ->headerClass = $settings['headerclass']; // prebije defaultni

        $this ->class = $settings['class'];

        $this ->style = $settings['style'];

        $align = $settings['align'];
        if ($align) $this ->align = $align;
    }


    // -----     SloupecZpracovaneDochazky     --------------------------------
    function getEditName($datum)
    {
        if (!$this ->lzeEditovat) return null;

        switch ($this ->typ) {
            case 'DV' :
                return 'DV_' . trim($this ->kodCasoveSlozky) . '_' . trim($this ->jednotka) . '_' . $datum; // napr. DV_220_H_123412345

            case 'DV_CHECK' :
                return 'DV_CHECK_' . trim($this ->kodCasoveSlozky) . '_' . trim($this ->jednotka) . '_' . $datum; // napr. DV_CHECK_220_H_123412345

            case 'DOCH1' :
                return ($this ->name ?: 'DOCH') . '1_' . $datum;
            case 'DOCH2' :
                return ($this ->name ?: 'DOCH') . '2_' . $datum;

            default : // P
                return ($this ->name ?: $this ->typ) . '_' . $datum;
        }
    }


    // -----     SloupecZpracovaneDochazky     --------------------------------
    function vratTextProHodnotu($hodnota)
    {
        switch ($this ->typ) {
            case 'DV' :
                switch ($this ->jednotka) {
                    case 'D' :
                    case 'K' :
                        return (isset($hodnota) && ($this ->zobrazitNuloveHodnoty  ||  (float)$hodnota))
                            ? StringUtils::format('number_2', $hodnota)
                            : '';

                    case 'P' :
                        return $hodnota;

                    case 'H' :
                    default :
                        if ((float)$hodnota) return StringUtils::format('minuty', round($hodnota * 60));
                        else return '';
                }

            case 'DV_CHECK' :
                return TextManager::_($hodnota ? 'STR_Yes' : 'STR_No');

            case 'DOCH1' :
            case 'DOCH2' :
                if ((float)$hodnota) return date('G:i', $hodnota);
                else return '';
        }

        return $hodnota;
    }



    // -----     SloupecZpracovaneDochazky     --------------------------------
    // V pripade chybne hodnoty vraci false. Pozor! nutno pouzit operator === pro porovnani!
    function vratHodnotuZTextu($text)
    {
        if (trim($text) === '') return 0; // prazdna hodnota

        switch ($this ->typ) {
            /** @noinspection PhpMissingBreakStatementInspection */
            case 'DV' :
                if ($this ->jednotka == 'P') {  // poznamka
                    return $text;
                }

                if ($this ->jednotka == 'D' || $this ->jednotka == 'K') {
                    if (!StringUtils::isFloat($text)) {
                        throw new \Exception( TextManager::_('Bad_number_format'));
                    }

                    return StringUtils::stringToFloat($text);
                }
                // jednotka 'H'
                return DateUtils::timeStringToFloat($text, true);

            case 'DV_CHECK' :
                return (int)$text;

            case 'DOCH1' :
            case 'DOCH2' :
                return DateUtils::timeStringToFloat($text, true); // povolitZkraceny = true

            case 'P' :
                return $text;
        }

        return false;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/sloupeczpracovanedochazky.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Editace;
use Ron\DateUtils;
use Ron\StringUtils;
use Ron\TextManager;

/**
 * Class SloupecZpracovaneDochazky
 * Nastaveni sloupce dennich vysledku
 */
class SloupecZpracovaneDochazky
{
    /** @var string */
    public $nadpis;

    /** @var string     Titulek, ktery se zobrazi v hlavicce */
    public $title;

    /** @var string     Typ zobrazenych dat ve sloupci */
    public $typ;

    /** @var string */
    public $kodCasoveSlozky;
    /** @var string     Jednotka pro denni vysledek - H, D, K, P */
    public $jednotka;
    /** @var bool       priznak, jestli se ma v hintu zobrazit puvodni dochazka */
    public $zobrazitPuvodni;
    /** @var bool       priznak, jestli se maji v hintu zobrazit pruchody */
    public $zobrazitPruchody;
    /** @var bool       priznak, jestli se maji zobrazit nulove hodnoty */
    public $zobrazitNuloveHodnoty;

    /** @var bool       jestli se ma sloupec zobrazit (default true, lze skryt napr. pomoci rozdeleni) */
    public $lzeZobrazit;
    /** @var bool       jestli je povolena editace sloupce */
    public $lzeEditovat;
    /** @var bool       jestli se muze editovat v jeste nezpracovanych dnech */
    public $editovatNezpracovanou;

    /** @var string     pro ktere rozdeleni se ma zobrazit - format textu je "typ/seznam kodu oddelenych strednikem" */
    public $filtrRozdeleni;
    /** @var string     kod profilu - sloupec se zobrazi jen uzivatelum se zadanym profilem */
    public $profil;
    /** @var string     kod prava, kterym se ridi zobrazeni sloupce */
    public $pravo;
    /** @var string     kod prava, kterym se ridi editace sloupce */
    public $pravoEditace;

    /** @var string     nadpis ve filtru - uzivatel si muze tuto polozku vypnout */
    public $filtrCaption;
    /** @var string     jedinecny kod pro zapinani a zapamatovani filtru */
    public $filtrKey;
    /** @var string     prepinaci skupina filtru  */
    public $filtrGroup;

    /** @var string     Nazev editu v HTML - pouzije se jen v nekterych sloupcich (DOCH1, DOCH2) - slouzi pro rozliseni vice sloupcu stejneho typu s ruznym nastavenim */
    public $name;

    /** @var string     u typu DOCH1 a DOCH2 se nastavi kod operace, ktera se vklada pri editaci prichodu a/nebo odchodu */
    public $operace;
    /** @var string     u typu DOCH1 a DOCH2 urcuje seznam operaci, ktere se budou zobrazovat, ostatni se ignoruji  */
    public $zapocitatOperace;
    /** @var string     u typu DOCH1 a DOCH2 urcuje seznam operaci, ktere se pri editaci "promazou" - lze pouzit napr. pro promazani prestavek */
    public $prepsatOperace;
    /** @var bool       priznak, ze se ma pouzit zobrazeny cas (defaultne zapocteny)  */
    public $zobrazenyCas;

    /** @var int        DV_ROZDELENI, DENNIVYSLEDEK_R, DENNIVYSLEDEK_R_E */
    public $typRozdeleni;
    /** @var string     Absence, graficka, DOCH_Z, DV_ROZDELENI, DENNIVYSLEDEK_R, DENNIVYSLEDEK_R_E */
    public $format;

    /** @var bool       u DOCH_G urcuje, jestli se ma zobrazit informace o smene. Mozne hodnoty: KAL/KAP/1/0, defaultni je 1 (=AUTO) */
    public $zobrazitSmenu;

    /** @var float      hodnota, ktera se zobrazi v paticce (mesicni vysledek) */
    public $soucet;
    public $zobrazitGraf;

    /** @var string     zarovnani */
    public $align;
    public $style;
    public $class;
    public $headerClass;

    /** @var bool       priznak, ze se nema pri zobrazeni pouzivat htmlconvert */
    public $noHtmlConvert;

    function __construct()
    {
        $this ->lzeZobrazit = true;
    }


    /**
     * @param string $nastaveniSloupce
     */
    function nastavPodleRetezce($nastaveniSloupce)
    {
        $poma = explode(':', $nastaveniSloupce, 5);

        $this ->typ = $poma[0];
        $this ->align = 'left';
        $this ->lzeEditovat = false;

        switch ($this ->typ) {
            case 'DV' : // DV:<kod>:H/D/K:0/1:Nadpis sloupce  -> denni vysledek
                $this ->kodCasoveSlozky = $poma[1];
                $this ->jednotka = $poma[2]; // H/D/K
                $this ->lzeEditovat = $poma[3] == '1';
                $this ->nadpis = $poma[4];
                $this ->align = 'right';
                break;

            case 'SCHVAL1' :
            case 'SCHVAL2' :
            case 'SCHVAL3' :
            case 'SCHVAL' :
                $this ->headerClass = 'schvaleni';
                break;

            case 'DATUM' :
                $this ->align = 'center';
                $this ->nadpis = $poma[1];
                if (!$this ->nadpis) {
                    $this ->nadpis = TextManager::_('Date');
                }
                break;

            case 'P' : // P:0/1:Nadpis sloupce -> poznamka ke dni
                $this ->lzeEditovat = $poma[1] == '1';
                $this ->nadpis = $poma[2];
                break;

            default :
                $this ->nadpis = $poma[1];
                break;
        }

    }


    /**
     * Nacte nastaveni z asociativniho pole (nactene z XML)
     * @param array $settings
     */
    function loadSettings($settings)
    {
        $this ->align = 'left';
        $this ->lzeEditovat = false;
        $this ->noHtmlConvert = false;

        $this ->typ = $settings['typ'];
        $this ->nadpis = TextManager::_($settings['nadpis']);
        $this ->title = TextManager::_($settings['title']);

        $this ->jednotka = $settings['jednotka']; // H/D/K/P

        $this->name = $settings['name'];

        switch ($this ->typ) {
            case 'DV' :
                if ($this ->jednotka != 'P') $this ->align = 'right';
                break;

            case 'DV_CHECK' :
                $this ->align = 'center';
                break;

            case 'SCHVAL1' :
            case 'SCHVAL2' :
            case 'SCHVAL3' :
            case 'SCHVAL' :
                $this ->headerClass = 'schvaleni';
                break;

            case 'DATUM' :
                $this ->align = 'center';
                if (!$this ->nadpis) $this ->nadpis = TextManager::_('Date');
                break;

            case 'DV_ROZDELENI' :
            case 'DENNIVYSLEDEK_R' :
            case 'DENNIVYSLEDEK_R_E' :
                $this ->typRozdeleni = (int)$settings['typrozdeleni'];
                if (!$this ->nadpis) $this ->nadpis = TextManager::_('Rozdeleni_vysledku');
                $this ->noHtmlConvert = true;
                break;

            case 'ABSENCE' :
            case 'DOC' : // dokumenty
            case 'KONTROLY' :
                $this ->noHtmlConvert = true;
                break;


            case 'DOCH1' :
            case 'DOCH2' :
                $this ->align = 'center';
                $this ->operace = $settings['operace'];
                $this ->zapocitatOperace = strtolower($settings['zapocitatoperace']);
                $this ->prepsatOperace = strtolower($settings['prepsatoperace']);
                $this ->zobrazitPuvodni = $settings['hintpuvodni'] == '1';
                $this ->zobrazitPruchody = $settings['hintpruchody'] == '1';
                $this ->zobrazenyCas = $settings['zobrazenycas'] == '1';
                $this ->name = $this ->name ?: 'DOCH';
                break;

            case 'DOCH_G' :
                $this ->zobrazitSmenu = $settings['zobrazitsmenu'];
                if ($this ->zobrazitSmenu === '') $this ->zobrazitSmenu = '1'; // defaultne automaticky podle kalendare
                break;
        }

        $this ->kodCasoveSlozky = $settings['kod'];
        $this ->lzeEditovat = $settings['editace'] == '1';
        //$this ->f_HTMLName = $element ->getAttribute('htmlname');
        $this ->editovatNezpracovanou = $settings['editovatnezpracovanou'] == '1';

        $this ->filtrRozdeleni = $settings['rozdeleni'];
        $this ->profil = $settings['profil'];
        $this ->pravo = $settings['pravo'];
        $this ->pravoEditace = $settings['pravoEditace'];

        $this ->zobrazitNuloveHodnoty = $settings['zobrazitNuloveHodnoty'] == '1';

        $this ->filtrKey = isset($settings['kodFiltru']) ? $settings['kodFiltru'] : $settings['kodfiltru'];
        $this ->filtrCaption = TextManager::_($settings['filtr']);
        $this ->filtrGroup = isset($settings['filtrGroup']) ? $settings['filtrGroup'] : $settings['filtrgroup'];

        $this ->format = $settings['format'];
        $this ->zobrazitGraf = isset($settings['zobrazitGraf']) ? $settings['zobrazitGraf'] == '1' : $settings['zobrazitgraf'] == '1';

        if ($settings['headerclass']) {
            // prebije defaultni
            $this ->headerClass = $settings['headerclass'];
        }

        $this ->class = $settings['class'];

        $this ->style = $settings['style'];

        $align = $settings['align'];
        if ($align) {
            $this ->align = $align;
        }
    }


    // -----     SloupecZpracovaneDochazky     --------------------------------
    function getEditName($datum)
    {
        if (!$this ->lzeEditovat) return null;

        switch ($this ->typ) {
            case 'DV' :
                return 'DV_' . trim($this ->kodCasoveSlozky) . '_' . trim($this ->jednotka) . '_' . $datum; // napr. DV_220_H_123412345

            case 'DV_CHECK' :
                return 'DV_CHECK_' . trim($this ->kodCasoveSlozky) . '_' . trim($this ->jednotka) . '_' . $datum; // napr. DV_CHECK_220_H_123412345

            case 'DOCH1' :
                return ($this ->name ?: 'DOCH') . '1_' . $datum;
            case 'DOCH2' :
                return ($this ->name ?: 'DOCH') . '2_' . $datum;

            default : // P
                return ($this ->name ?: $this ->typ) . '_' . $datum;
        }
    }


    // -----     SloupecZpracovaneDochazky     --------------------------------
    function vratTextProHodnotu($hodnota)
    {
        switch ($this ->typ) {
            case 'DV' :
                switch ($this ->jednotka) {
                    case 'D' :
                    case 'K' :
                        return (isset($hodnota) && ($this ->zobrazitNuloveHodnoty  ||  (float)$hodnota))
                            ? StringUtils::format('number_2', $hodnota)
                            : '';

                    case 'P' :
                        return $hodnota;

                    case 'H' :
                    default :
                        if ((float)$hodnota) return StringUtils::format('minuty', round($hodnota * 60));
                        else return '';
                }

            case 'DV_CHECK' :
                return TextManager::_($hodnota ? 'STR_Yes' : 'STR_No');

            case 'DOCH1' :
            case 'DOCH2' :
                if ((float)$hodnota) return date('G:i', $hodnota);
                else return '';
        }

        return $hodnota;
    }



    // -----     SloupecZpracovaneDochazky     --------------------------------
    // V pripade chybne hodnoty vraci false. Pozor! nutno pouzit operator === pro porovnani!
    function vratHodnotuZTextu($text)
    {
        if (trim($text) === '') return 0; // prazdna hodnota

        switch ($this ->typ) {
            /** @noinspection PhpMissingBreakStatementInspection */
            case 'DV' :
                if ($this ->jednotka == 'P') {  // poznamka
                    return $text;
                }

                if ($this ->jednotka == 'D' || $this ->jednotka == 'K') {
                    if (!StringUtils::isFloat($text)) {
                        throw new \Exception( TextManager::_('Bad_number_format'));
                    }

                    return StringUtils::stringToFloat($text);
                }
                // jednotka 'H'
                return DateUtils::timeStringToFloat($text, true);

            case 'DV_CHECK' :
                return (int)$text;

            case 'DOCH1' :
            case 'DOCH2' :
                return DateUtils::timeStringToFloat($text, true); // povolitZkraceny = true

            case 'P' :
                return $text;
        }

        return false;
    }
}
